@@ -24,7 +24,7 @@ import pandas as pd
 
 from cpacspy.aeromap import AeroMap
 from cpacspy.aircraft import Aircraft
-from cpacspy.cpacsfunctions import open_tixi
+from cpacspy.cpacsfunctions import open_tigl, open_tixi
 from cpacspy.utils import AEROPERFORMANCE_XPATH
 
 
@@ -35,6 +35,7 @@ class CPACS:
         # CPACS
         self.cpacs_file = cpacs_file
         self.tixi = open_tixi(cpacs_file)
+        self.tigl = open_tigl(self.tixi)
 
         # Aircraft name
         ac_name_xpath = '/cpacs/header/name'
@@ -42,7 +43,7 @@ class CPACS:
             self.ac_name = self.tixi.getTextElement(ac_name_xpath)
 
         # Aircraft data
-        self.aircraft = Aircraft(self.tixi)
+        self.aircraft = Aircraft(self.tixi,self.tigl)
 
         # AeroMaps
         self.aeromap = []
@@ -52,12 +53,12 @@ class CPACS:
     def load_all_aeromaps(self):
         """ Load all the aeromap present in the CPACS file as object. """
 
-        for aeromap_uid in self.get_uid_list():
+        for aeromap_uid in self.get_aeromap_uid_list():
             aeromap = AeroMap(self.tixi,aeromap_uid)
             self.aeromap.append(aeromap)
             self.nb_aeromap += 1
 
-    def get_uid_list(self):
+    def get_aeromap_uid_list(self):
         """ Get the list of all aeroMap UID. """
 
         uid_list = []
@@ -91,7 +92,7 @@ class CPACS:
         if ' ' in uid:
             raise ValueError('AeroMap uid should not contain any space!')
 
-        if uid not in self.get_uid_list():
+        if uid not in self.get_aeromap_uid_list():
             new_aeromap = AeroMap(self.tixi,uid,create_new=True)
             self.aeromap.append(new_aeromap)
             self.nb_aeromap += 1
@@ -118,10 +119,10 @@ class CPACS:
         """ Duplicate an aeromap and retrun the new aeromap object. """
 
         # Check uid's
-        if not uid_base in self.get_uid_list():
+        if not uid_base in self.get_aeromap_uid_list():
             raise ValueError('The AeroMap to duplicate does not exit!')
 
-        if uid_duplicate in self.get_uid_list():
+        if uid_duplicate in self.get_aeromap_uid_list():
             raise ValueError('This uid for the duplicate already exit!')
 
         # Get AeroMap and duplicate
@@ -161,13 +162,15 @@ class CPACS:
     def __str__(self): 
 
         text_line = []
-        text_line.append('\n----------------------------------------------------------------------------------------------------')
+        text_line.append('\nCPACS file -----------------------------------------------------------------------------------------')
+        text_line.append(' ')
         text_line.append(f'Aircraft name : {self.ac_name}')
         text_line.append(f'CPACS file path: {self.cpacs_file}')
         text_line.append(' ')
-        text_line.append('Aeromaps list:')
-        for aeromap_uid in self.get_uid_list():
-            text_line.append(aeromap_uid)
+        text_line.append('List of AeroMaps:')
+        for aeromap_uid in self.get_aeromap_uid_list():
+            text_line.append('  ' + aeromap_uid)
+        text_line.append(' ')
         text_line.append('----------------------------------------------------------------------------------------------------\n')
 
         return ('\n').join(text_line)
